#! /bin/sh
# /usr/bin/
# This script is used to bring up the AF-5000 Wi-Fi networks.

###########
# LOGGING #
###########

LOGFILE=/home/root/logs/SYSLOG.ALS
IFNAME=($(ifconfig -a | grep -o "^wlan[0-9]\+"))
IFLEN=${#IFNAME[@]}

list_if() {
  for ((i = 0; i != IFLEN; i++)); do
     echo "RC-WIFI: Found $i: '${IFNAME[i]}'" >> $LOGFILE
  done
}

#######################
# INTERFACE FUNCTIONS #
#######################

# Close down DNS and Access Point Daemon
clean() {
  sed -i 's/wlan[1-9]/wlan0/g' /etc/udev/rules.d/70-persistent-net.rules
  if pidof -x "dnsmasq" >/dev/null; then
    echo "RC-WIFI: Stopping dnsmasq process." >> $LOGFILE
    pkill dnsmasq
  fi
  if pidof -x "hostapd" >/dev/null; then
    echo "RC-WIFI: Stopping hostapd process." >> $LOGFILE
    pkill hostapd
  fi
  if pidof -x "wpa_supplicant" >/dev/null; then
    echo "RC-WIFI: Stopping wpa_supplicant." >> $LOGFILE
    pkill wpa_supplicant
  fi
}

# Function to bring up a network interface.
nic_up() {
  echo "RC-WIFI: Configuring ${IFNAME[0]} as client" >> $LOGFILE
  /sbin/ifconfig ${IFNAME[0]} up
}

client_up() {
  #Startup our network interface.
  LAN_COMMAND=`/sbin/ifconfig | /usr/bin/grep -oh wlan[0-9]`
  `usr/local/bin/wpa_supplicant -B -i$LAN_COMMAND -c/etc/wpasupplicant.conf >> /home/root/logs/wpa_startup.log`

}

# Function to take down a network interface:
host_up() {
  echo "RC-WIFI: Configuring ${IFNAME[0]} as host" >> $LOGFILE
  /sbin/ifconfig ${IFNAME[0]} up 192.168.10.1 netmask 255.255.255.0
  sleep 5
  #echo "RC-WIFI: Starting dnsmasq." >> $LOGFILE
  /usr/local/bin/dnsmasq
  #echo "RC-WIFI: Configuring iptables." >> $LOGFILE
  /usr/sbin/iptables --flush
  /usr/sbin/iptables --table nat --flush
  /usr/sbin/iptables --delete-chain
  /usr/sbin/iptables --table nat --append POSTROUTING --out-interface lo -j MASQUERADE
  /usr/sbin/iptables --append FORWARD --in-interface ${IFNAME[0]} -j ACCEPT
  /sbin/sysctl -w net.ipv4.ip_forward=1 1>> $LOGFILE
  /usr/local/bin/hostapd -B /etc/hostapd/hostapd.conf 1>> $LOGFILE
}

############
### MAIN ###
############

clean
nic_up

case "$1" in
client_start)
  client_up
  ;;
host_start)
  host_up
  ;;
list)
  list_if
  ;;
*) # The app can convert host to client
  ;;
esac

# End of /usr/bin/rc.wifi.sh
